summaryrefslogtreecommitdiff
path: root/TAO/TAO_IDL/be_include/be_visitor_interface/interface_sh.h
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/TAO_IDL/be_include/be_visitor_interface/interface_sh.h')
-rw-r--r--TAO/TAO_IDL/be_include/be_visitor_interface/interface_sh.h46
1 files changed, 26 insertions, 20 deletions
diff --git a/TAO/TAO_IDL/be_include/be_visitor_interface/interface_sh.h b/TAO/TAO_IDL/be_include/be_visitor_interface/interface_sh.h
index f62e1e28d5d..f7fb788769b 100644
--- a/TAO/TAO_IDL/be_include/be_visitor_interface/interface_sh.h
+++ b/TAO/TAO_IDL/be_include/be_visitor_interface/interface_sh.h
@@ -24,27 +24,33 @@
class be_visitor_interface_sh : public be_visitor_interface
{
- //
- // = TITLE
- // be_visitor_interface_sh
- //
- // = DESCRIPTION
- // This is a concrete visitor to generate the server header for interface
- //
- //
- public:
- be_visitor_interface_sh (be_visitor_context *ctx);
- // constructor
+ //
+ // = TITLE
+ // be_visitor_interface_sh
+ //
+ // = DESCRIPTION
+ // This is a concrete visitor to generate the server header for interface
+ //
+ //
+public:
+ be_visitor_interface_sh (be_visitor_context *ctx);
+ // constructor
+
+ ~be_visitor_interface_sh (void);
+ // destructor
+
+ virtual int visit_interface (be_interface *node);
+ // set the right context and make a visitor
- ~be_visitor_interface_sh (void);
- // destructor
-
- virtual int visit_interface (be_interface *node);
- // set the right context and make a visitor
-
- protected:
- virtual void this_method (be_interface *node);
- virtual int generate_amh_classes (be_interface *node);
+ static int gen_abstract_ops_helper (be_interface *node,
+ be_interface *base,
+ TAO_OutStream *os);
+ // Helper to generate the declarations for the operations
+ // of any abstract parents we may have.
+
+protected:
+ virtual void this_method (be_interface *node);
+ virtual int generate_amh_classes (be_interface *node);
};
#endif /* _BE_INTERFACE_INTERFACE_SH_H_ */